@@ -20,16 +20,18 @@
 #include "kateview_test.h"
 #include "moc_kateview_test.cpp"
 
-#include <kateglobal.h>
-#include <katedocument.h>
-#include <kateview.h>
-#include <ktexteditor/movingcursor.h>
-#include <kateconfig.h>
 #include <katebuffer.h>
+#include <kateconfig.h>
+#include <katedocument.h>
+#include <kateglobal.h>
+#include <kateview.h>
 #include <ktexteditor/message.h>
+#include <ktexteditor/movingcursor.h>
 
-#include <QtTestWidgets>
 #include <QTemporaryFile>
+#include <QtTestWidgets>
+
+#define testNewRow() (QTest::newRow(QString("line %1").arg(__LINE__).toLatin1().data()))
 
 using namespace KTextEditor;
 
@@ -50,33 +52,28 @@ void KateViewTest::testCoordinatesToCursor()
     KTextEditor::DocumentPrivate doc(false, false);
     doc.setText("Hi World!\nHi\n");
 
-    KTextEditor::View* view1 = static_cast<KTextEditor::View*>(doc.createView(nullptr));
+    KTextEditor::View *view1 = static_cast<KTextEditor::View *>(doc.createView(nullptr));
+    view1->resize(400, 300);
     view1->show();
 
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(0, 2))),
-             KTextEditor::Cursor(0, 2));
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 1))),
-             KTextEditor::Cursor(1, 1));
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(0, 2))), KTextEditor::Cursor(0, 2));
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 1))), KTextEditor::Cursor(1, 1));
     // behind end of line should give an invalid cursor
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 5))),
-             KTextEditor::Cursor::invalid());
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 5))), KTextEditor::Cursor::invalid());
     QCOMPARE(view1->cursorToCoordinate(KTextEditor::Cursor(3, 1)), QPoint(-1, -1));
 
     // check consistency between cursorToCoordinate(view->cursorPosition() and cursorPositionCoordinates()
     // random position
     view1->setCursorPosition(KTextEditor::Cursor(0, 3));
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(view1->cursorPosition())),
-             KTextEditor::Cursor(0, 3));
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(view1->cursorPosition())), KTextEditor::Cursor(0, 3));
     QCOMPARE(view1->coordinatesToCursor(view1->cursorPositionCoordinates()), KTextEditor::Cursor(0, 3));
     // end of line
     view1->setCursorPosition(KTextEditor::Cursor(0, 9));
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(0, 9))),
-             KTextEditor::Cursor(0, 9));
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(0, 9))), KTextEditor::Cursor(0, 9));
     QCOMPARE(view1->coordinatesToCursor(view1->cursorPositionCoordinates()), KTextEditor::Cursor(0, 9));
     // empty line
     view1->setCursorPosition(KTextEditor::Cursor(2, 0));
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(2, 0))),
-             KTextEditor::Cursor(2, 0));
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(2, 0))), KTextEditor::Cursor(2, 0));
     QCOMPARE(view1->coordinatesToCursor(view1->cursorPositionCoordinates()), KTextEditor::Cursor(2, 0));
 
     // same test again, but with message widget on top visible
@@ -86,13 +83,10 @@ void KateViewTest::testCoordinatesToCursor()
     // wait 500ms until show animation is finished, so the message widget is visible
     QTest::qWait(500);
 
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(0, 2))),
-             KTextEditor::Cursor(0, 2));
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 1))),
-             KTextEditor::Cursor(1, 1));
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(0, 2))), KTextEditor::Cursor(0, 2));
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 1))), KTextEditor::Cursor(1, 1));
     // behind end of line should give an invalid cursor
-    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 5))),
-             KTextEditor::Cursor::invalid());
+    QCOMPARE(view1->coordinatesToCursor(view1->cursorToCoordinate(KTextEditor::Cursor(1, 5))), KTextEditor::Cursor::invalid());
     QCOMPARE(view1->cursorToCoordinate(KTextEditor::Cursor(3, 1)), QPoint(-1, -1));
 }
 
@@ -170,6 +164,19 @@ void KateViewTest::testLowerCaseBlockSelection()
     QCOMPARE(doc.text(), QString("ny\nnyy\n"));
 }
 
+namespace
+{
+QWidget *findViewInternal(KTextEditor::View *view)
+{
+    for (QObject *child : view->children()) {
+        if (child->metaObject()->className() == QByteArrayLiteral("KateViewInternal")) {
+            return qobject_cast<QWidget *>(child);
+        }
+    }
+    return nullptr;
+}
+}
+
 void KateViewTest::testSelection()
 {
     // see also: https://bugs.kde.org/show_bug.cgi?id=277422
@@ -197,13 +204,7 @@ void KateViewTest::testSelection()
     view->resize(100, 200);
     view->show();
 
-    QObject *internalView = nullptr;
-    foreach (QObject* child, view->children()) {
-        if (child->metaObject()->className() == QByteArrayLiteral("KateViewInternal")) {
-            internalView = child;
-            break;
-        }
-    }
+    QObject *internalView = findViewInternal(view);
     QVERIFY(internalView);
 
     const QPoint afterA = view->cursorToCoordinate(Cursor(0, 1));
@@ -211,61 +212,98 @@ void KateViewTest::testSelection()
     const QPoint afterC = view->cursorToCoordinate(Cursor(2, 1));
 
     // click after A
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterA,
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterA, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterA,
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterA, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
     QCOMPARE(view->cursorPosition(), Cursor(0, 1));
     // drag to right
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterA,
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterA, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseMove, afterA + QPoint(50, 0),
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseMove, afterA + QPoint(50, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterA + QPoint(50, 0),
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterA + QPoint(50, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
     QCOMPARE(view->cursorPosition(), Cursor(0, 1));
     QVERIFY(!view->selection());
 
     // click after C
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterC,
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterC, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterC,
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::NoModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterC, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier));
 
     QCOMPARE(view->cursorPosition(), Cursor(2, 1));
     // shift+click after B
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterB,
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::ShiftModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonPress, afterB, Qt::LeftButton, Qt::LeftButton, Qt::ShiftModifier));
 
-    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterB,
-                                Qt::LeftButton, Qt::LeftButton,
-                                Qt::ShiftModifier));
+    QCoreApplication::sendEvent(internalView, new QMouseEvent(QEvent::MouseButtonRelease, afterB, Qt::LeftButton, Qt::LeftButton, Qt::ShiftModifier));
 
     QCOMPARE(view->cursorPosition(), Cursor(1, 1));
     QCOMPARE(view->selectionRange(), Range(1, 1, 2, 1));
 }
 
+void KateViewTest::testDeselectByArrowKeys_data()
+{
+    QTest::addColumn<QString>("text");
+
+    testNewRow() << "foobarhaz";
+    testNewRow() << "كلسشمن يتبكسب"; // We all win, translates Google
+}
+
+void KateViewTest::testDeselectByArrowKeys()
+{
+    QFETCH(QString, text);
+
+    KTextEditor::DocumentPrivate doc;
+    doc.setText(text);
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    KTextEditor::Cursor cur1(0, 3); // Start of bar: foo|barhaz
+    KTextEditor::Cursor cur2(0, 6); //   End of bar: foobar|haz
+    KTextEditor::Cursor curDelta(0, 1);
+    Range range(cur1, cur2); // Select "bar"
+
+    // RTL drives me nuts!
+    KTextEditor::Cursor help;
+    if (text.isRightToLeft()) {
+        help = cur1;
+        cur1 = cur2;
+        cur2 = help;
+    }
+
+    view->setSelection(range);
+    view->setCursorPositionInternal(cur1);
+    view->cursorLeft();
+    QCOMPARE(view->cursorPosition(), cur1); // Be at begin: foo|barhaz
+    QCOMPARE(view->selection(), false);
+
+    view->setSelection(range);
+    view->setCursorPositionInternal(cur1);
+    view->cursorRight();
+    QCOMPARE(view->cursorPosition(), cur2); // Be at end: foobar|haz
+    QCOMPARE(view->selection(), false);
+
+    view->config()->setValue(KateViewConfig::PersistentSelection, true);
+
+    view->setSelection(range);
+    view->setCursorPositionInternal(cur1);
+    view->cursorLeft();
+    // RTL drives me nuts!
+    help = text.isRightToLeft() ? (cur1 + curDelta) : (cur1 - curDelta);
+    QCOMPARE(view->cursorPosition(), help); // Be one left: fo|obarhaz
+    QCOMPARE(view->selection(), true);
+
+    view->setSelection(range);
+    view->setCursorPositionInternal(cur1);
+    view->cursorRight();
+    // RTL drives me nuts!
+    help = text.isRightToLeft() ? (cur1 - curDelta) : (cur1 + curDelta);
+    QCOMPARE(view->cursorPosition(), help); // Be one right: foob|arhaz
+    QCOMPARE(view->selection(), true);
+}
+
 void KateViewTest::testKillline()
 {
     KTextEditor::DocumentPrivate doc;
-    doc.insertLines(0, QStringList()
-        << "foo"
-        << "bar"
-        << "baz"
-    );
+    doc.insertLines(0, {"foo", "bar", "baz"});
 
     KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
 
@@ -277,12 +315,7 @@ void KateViewTest::testKillline()
     doc.clear();
     QVERIFY(doc.isEmpty());
 
-    doc.insertLines(0, QStringList()
-        << "foo"
-        << "bar"
-        << "baz"
-        << "xxx"
-    );
+    doc.insertLines(0, {"foo", "bar", "baz", "xxx"});
 
     view->setCursorPositionInternal(KTextEditor::Cursor(1, 2));
     view->shiftDown();
@@ -291,6 +324,41 @@ void KateViewTest::testKillline()
     QCOMPARE(doc.text(), QLatin1String("foo\nxxx\n"));
 }
 
+void KateViewTest::testScrollPastEndOfDocument()
+{
+    // bug 306745
+    KTextEditor::DocumentPrivate doc;
+    doc.setText(
+        QStringLiteral("0000000000\n"
+                       "1111111111\n"
+                       "2222222222\n"
+                       "3333333333\n"
+                       "4444444444"));
+    QCOMPARE(doc.lines(), 5);
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view->setCursorPosition({3, 5});
+    view->resize(400, 300);
+    view->show();
+
+    // enable "[x] Scroll past end of document"
+    view->config()->setValue(KateViewConfig::ScrollPastEnd, true);
+    QCOMPARE(view->config()->scrollPastEnd(), true);
+
+    // disable dynamic word wrap
+    view->config()->setDynWordWrap(false);
+    QCOMPARE(view->config()->dynWordWrap(), false);
+
+    view->scrollDown();
+    view->scrollDown();
+    view->scrollDown();
+    // at this point, only lines 3333333333 and 4444444444 are visible.
+    view->down();
+    QCOMPARE(view->cursorPosition(), KTextEditor::Cursor(4, 5));
+    // verify, that only lines 3333333333 and 4444444444 are still visible.
+    QCOMPARE(view->firstDisplayedLineInternal(KTextEditor::View::RealLine), 3);
+}
+
 void KateViewTest::testFoldFirstLine()
 {
     QTemporaryFile file("XXXXXX.cpp");
@@ -308,14 +376,14 @@ void KateViewTest::testFoldFirstLine()
     QCOMPARE(doc.highlightingMode(), QString("C++"));
 
     KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
-    view->config()->setFoldFirstLine(false);
+    view->config()->setValue(KateViewConfig::FoldFirstLine, false);
     view->setCursorPosition({4, 0});
 
     // initially, nothing is folded
     QVERIFY(view->textFolding().isLineVisible(1));
 
     // now change the config, and expect the header to be folded
-    view->config()->setFoldFirstLine(true);
+    view->config()->setValue(KateViewConfig::FoldFirstLine, true);
     qint64 foldedRangeId = 0;
     QVERIFY(!view->textFolding().isLineVisible(1, &foldedRangeId));
 
@@ -338,67 +406,98 @@ void KateViewTest::testFoldFirstLine()
 void KateViewTest::testDragAndDrop()
 {
     KTextEditor::DocumentPrivate doc(false, false);
-    doc.setText("line0\n"
-                "line1\n"
-                "line2\n"
-                "\n"
-                "line4");
+    doc.setText(
+        "line0\n"
+        "line1\n"
+        "line2\n"
+        "\n"
+        "line4");
 
-    KTextEditor::View* view = static_cast<KTextEditor::View*>(doc.createView(nullptr));
+    KTextEditor::View *view = static_cast<KTextEditor::View *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
 
-    QWidget *internalView = nullptr;
-    foreach (QObject* child, view->children()) {
-        if (child->metaObject()->className() == QByteArrayLiteral("KateViewInternal")) {
-            internalView = qobject_cast<QWidget *>(child);
-            break;
-        }
-    }
+    QWidget *internalView = findViewInternal(view);
     QVERIFY(internalView);
 
     // select "line1\n"
     view->setSelection(Range(1, 0, 2, 0));
     QCOMPARE(view->selectionRange(), Range(1, 0, 2, 0));
 
-    QTest::qWaitForWindowExposed(view);
+    QVERIFY(QTest::qWaitForWindowExposed(view));
+    QTest::qWait(0); // For whatever reason needed
+
     const QPoint startDragPos = internalView->mapFrom(view, view->cursorToCoordinate(KTextEditor::Cursor(1, 2)));
     const QPoint endDragPos = internalView->mapFrom(view, view->cursorToCoordinate(KTextEditor::Cursor(3, 0)));
     const QPoint gStartDragPos = internalView->mapToGlobal(startDragPos);
     const QPoint gEndDragPos = internalView->mapToGlobal(endDragPos);
 
     // now drag and drop selected text to Cursor(3, 0)
-    QMouseEvent pressEvent(QEvent::MouseButtonPress, startDragPos, gStartDragPos,
-                                Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+    QMouseEvent pressEvent(QEvent::MouseButtonPress, startDragPos, gStartDragPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
     QCoreApplication::sendEvent(internalView, &pressEvent);
 
     // ugly workaround: Drag & Drop has own blocking event queue. Therefore, we need a single-shot timer to
     // break out of the blocking event queue, see (*)
-    QTimer::singleShot(50, [&](){
-        QMouseEvent moveEvent(QEvent::MouseMove, endDragPos + QPoint(5, 0), gEndDragPos + QPoint(5, 0),
-                            Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
-        QMouseEvent releaseEvent(QEvent::MouseButtonRelease, endDragPos, gEndDragPos,
-                            Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
+    QTimer::singleShot(50, [&]() {
+        QMouseEvent moveEvent(QEvent::MouseMove, endDragPos + QPoint(5, 0), gEndDragPos + QPoint(5, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+        QMouseEvent releaseEvent(QEvent::MouseButtonRelease, endDragPos, gEndDragPos, Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
         QCoreApplication::sendEvent(internalView, &moveEvent);
         QCoreApplication::sendEvent(internalView, &releaseEvent);
     });
 
     // (*) this somehow blocks...
-    QMouseEvent moveEvent1(QEvent::MouseMove, endDragPos + QPoint(10, 0), gEndDragPos + QPoint(10, 0),
-                           Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+    QMouseEvent moveEvent1(QEvent::MouseMove, endDragPos + QPoint(10, 0), gEndDragPos + QPoint(10, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
     QCoreApplication::sendEvent(internalView, &moveEvent1);
 
     QTest::qWait(100);
 
     // final tests of dragged text
-    QCOMPARE(doc.text(), QString("line0\n"
-                                 "line2\n"
-                                 "line1\n"
-                                 "\n"
-                                 "line4"));
+    QCOMPARE(doc.text(),
+             QString("line0\n"
+                     "line2\n"
+                     "line1\n"
+                     "\n"
+                     "line4"));
 
     QCOMPARE(view->cursorPosition(), KTextEditor::Cursor(3, 0));
     QCOMPARE(view->selectionRange(), Range(2, 0, 3, 0));
 }
 
+// test for bug https://bugs.kde.org/402594
+void KateViewTest::testGotoMatchingBracket()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    doc.setText("foo(bar)baz");
+    //           0123456789
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    const KTextEditor::Cursor cursor1(0, 3); // Starting point on open (
+    const KTextEditor::Cursor cursor2(0, 8); // Insert Mode differ slightly from...
+    const KTextEditor::Cursor cursor3(0, 7); // Overwrite Mode
+
+    doc.config()->setOvr(false); // Insert Mode
+
+    view->setCursorPosition(cursor1);
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor2);
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor1);
+
+    // Currently has it in Insert Mode also to work when the cursor is placed inside the parentheses
+    view->setCursorPosition(cursor1 + KTextEditor::Cursor(0, 1));
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor2);
+    view->setCursorPosition(cursor2 + KTextEditor::Cursor(0, -1));
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor1);
+
+    doc.config()->setOvr(true); // Overwrite Mode
+
+    view->setCursorPosition(cursor1);
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor3);
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor1);
+}
+
 // kate: indent-mode cstyle; indent-width 4; replace-tabs on;
