@@ -1,23 +1,25 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef __KATE_NORMAL_INPUT_MODE_H__
-#define __KATE_NORMAL_INPUT_MODE_H__
+    Copyright (C) KDE Developers
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
+
+#ifndef KATE_NORMAL_INPUT_MODE_H
+#define KATE_NORMAL_INPUT_MODE_H
 
 #include "kateabstractinputmode.h"
 
@@ -27,7 +29,7 @@ class KateCommandLineBar;
 
 class KateNormalInputMode : public KateAbstractInputMode
 {
-    KateNormalInputMode(KateViewInternal *viewInternal);
+    explicit KateNormalInputMode(KateViewInternal *viewInternal);
     friend KateNormalInputModeFactory;
 
 public:
@@ -82,11 +84,7 @@ private:
      *   - Setup Power mode, aka find & replace: Also potential new search pattern
      *   - Use current mode and current search pattern or if no Search bar exists, launch Incremental mode
      */
-    enum SearchBarMode {
-        IncrementalSearchBar,
-        PowerSearchBar,
-        IncrementalSearchBarOrKeepMode
-    };
+    enum SearchBarMode { IncrementalSearchBar, PowerSearchBar, IncrementalSearchBarOrKeepMode };
 
     /**
      * Get search bar, create it on demand. (with right mode)
