@@ -1,46 +1,42 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2008-2010 by Michel Ludwig <michel.ludwig@kdemail.net>
- *  Copyright (C) 2009 by Joseph Wenninger <jowenn@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-/* If ever threads should be used again, thread communication and
- * synchronization ought to be done with blocking queued signal connections.
- */
+    Copyright (C) 2008-2010 by Michel Ludwig <michel.ludwig@kdemail.net>
+    Copyright (C) 2009 by Joseph Wenninger <jowenn@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "ontheflycheck.h"
 
 #include <QTimer>
 
+#include "katebuffer.h"
 #include "kateconfig.h"
 #include "kateglobal.h"
+#include "katepartdebug.h"
 #include "katerenderer.h"
-#include "katebuffer.h"
 #include "kateview.h"
 #include "spellcheck.h"
 #include "spellingmenu.h"
-#include "katepartdebug.h"
 
 #define ON_THE_FLY_DEBUG qCDebug(LOG_KTE)
 
-namespace {
-
-inline const QPair<KTextEditor::MovingRange *, QString>& invalidSpellCheckQueueItem()
+namespace
+{
+inline const QPair<KTextEditor::MovingRange *, QString> &invalidSpellCheckQueueItem()
 {
     static const auto item = QPair<KTextEditor::MovingRange *, QString>(nullptr, QString());
     return item;
@@ -49,11 +45,11 @@ inline const QPair<KTextEditor::MovingRange *, QString>& invalidSpellCheckQueueI
 }
 
 KateOnTheFlyChecker::KateOnTheFlyChecker(KTextEditor::DocumentPrivate *document)
-    : QObject(document),
-      m_document(document),
-      m_backgroundChecker(NULL),
-      m_currentlyCheckedItem(invalidSpellCheckQueueItem()),
-      m_refreshView(NULL)
+    : QObject(document)
+    , m_document(document)
+    , m_backgroundChecker(nullptr)
+    , m_currentlyCheckedItem(invalidSpellCheckQueueItem())
+    , m_refreshView(nullptr)
 {
     ON_THE_FLY_DEBUG << "created";
 
@@ -61,21 +57,19 @@ KateOnTheFlyChecker::KateOnTheFlyChecker(KTextEditor::DocumentPrivate *document)
     m_viewRefreshTimer->setSingleShot(true);
     connect(m_viewRefreshTimer, SIGNAL(timeout()), this, SLOT(viewRefreshTimeout()));
 
-    connect(document, &KTextEditor::DocumentPrivate::textInserted,
-            this, &KateOnTheFlyChecker::textInserted);
-    connect(document, &KTextEditor::DocumentPrivate::textRemoved,
-            this, &KateOnTheFlyChecker::textRemoved);
-    connect(document, SIGNAL(viewCreated(KTextEditor::Document*,KTextEditor::View*)),
-            this, SLOT(addView(KTextEditor::Document*,KTextEditor::View*)));
-    connect(document, SIGNAL(highlightingModeChanged(KTextEditor::Document*)),
-            this, SLOT(updateConfig()));
-    connect(&document->buffer(), SIGNAL(respellCheckBlock(int,int)),
-            this, SLOT(handleRespellCheckBlock(int,int)));
+    connect(document, &KTextEditor::DocumentPrivate::textInserted, this, &KateOnTheFlyChecker::textInserted);
+    connect(document, &KTextEditor::DocumentPrivate::textRemoved, this, &KateOnTheFlyChecker::textRemoved);
+    connect(document, SIGNAL(viewCreated(KTextEditor::Document *, KTextEditor::View *)), this, SLOT(addView(KTextEditor::Document *, KTextEditor::View *)));
+    connect(document, SIGNAL(highlightingModeChanged(KTextEditor::Document *)), this, SLOT(updateConfig()));
+    connect(&document->buffer(), SIGNAL(respellCheckBlock(int, int)), this, SLOT(handleRespellCheckBlock(int, int)));
+
+    connect(document, &KTextEditor::Document::reloaded, this, [this](KTextEditor::Document *) { refreshSpellCheck(); });
 
     // load the settings for the speller
     updateConfig();
 
-    foreach (KTextEditor::View *view, document->views()) {
+    const auto views = document->views();
+    for (KTextEditor::View *view : views) {
         addView(document, view);
     }
     refreshSpellCheck();
@@ -88,7 +82,7 @@ KateOnTheFlyChecker::~KateOnTheFlyChecker()
 
 QPair<KTextEditor::Range, QString> KateOnTheFlyChecker::getMisspelledItem(const KTextEditor::Cursor &cursor) const
 {
-    foreach (const MisspelledItem &item, m_misspelledList) {
+    for (const MisspelledItem &item : m_misspelledList) {
         KTextEditor::MovingRange *movingRange = item.first;
         if (movingRange->contains(cursor)) {
             return QPair<KTextEditor::Range, QString>(*movingRange, item.second);
@@ -99,7 +93,7 @@ QPair<KTextEditor::Range, QString> KateOnTheFlyChecker::getMisspelledItem(const
 
 QString KateOnTheFlyChecker::dictionaryForMisspelledRange(const KTextEditor::Range &range) const
 {
-    foreach (const MisspelledItem &item, m_misspelledList) {
+    for (const MisspelledItem &item : m_misspelledList) {
         KTextEditor::MovingRange *movingRange = item.first;
         if (*movingRange == range) {
             return item.second;
@@ -110,8 +104,8 @@ QString KateOnTheFlyChecker::dictionaryForMisspelledRange(const KTextEditor::Ran
 
 void KateOnTheFlyChecker::clearMisspellingForWord(const QString &word)
 {
-    MisspelledList misspelledList = m_misspelledList; // make a copy
-    foreach (const MisspelledItem &item, misspelledList) {
+    const MisspelledList misspelledList = m_misspelledList; // make a copy
+    for (const MisspelledItem &item : misspelledList) {
         KTextEditor::MovingRange *movingRange = item.first;
         if (m_document->text(*movingRange) == word) {
             deleteMovingRange(movingRange);
@@ -150,7 +144,8 @@ void KateOnTheFlyChecker::textInserted(KTextEditor::Document *document, const KT
         return;
     }
     // for performance reasons we only want to schedule spellchecks for ranges that are visible
-    foreach (KTextEditor::View *i, m_document->views()) {
+    const auto views = m_document->views();
+    for (KTextEditor::View *i : views) {
         KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(i);
         KTextEditor::Range visibleIntersection = documentIntersection.intersect(view->visibleRange());
         if (visibleIntersection.isValid()) { // allow empty intersections
@@ -191,8 +186,7 @@ void KateOnTheFlyChecker::handleInsertedText(const KTextEditor::Range &range)
             spellCheckInProgress = false;
         }
     }
-    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin();
-            i != m_spellCheckQueue.end();) {
+    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin(); i != m_spellCheckQueue.end();) {
         KTextEditor::MovingRange *spellCheckRange = (*i).first;
         if (spellCheckRange->contains(consideredRange)) {
             consideredRange = *spellCheckRange;
@@ -212,8 +206,7 @@ void KateOnTheFlyChecker::handleInsertedText(const KTextEditor::Range &range)
             ++i;
         }
     }
-    KTextEditor::Range spellCheckRange = findWordBoundaries(consideredRange.start(),
-                                         consideredRange.end());
+    KTextEditor::Range spellCheckRange = findWordBoundaries(consideredRange.start(), consideredRange.end());
     const bool emptyAtStart = m_spellCheckQueue.isEmpty();
 
     queueSpellCheckVisibleRange(spellCheckRange);
@@ -236,11 +229,12 @@ void KateOnTheFlyChecker::textRemoved(KTextEditor::Document *document, const KTe
     // don't consider a range that is behind the end of the document
     const KTextEditor::Range documentIntersection = m_document->documentRange().intersect(range);
     if (!documentIntersection.isValid()) { // the intersection might however be empty if the last
-        return;                             // word has been removed, for example
+        return;                            // word has been removed, for example
     }
 
     // for performance reasons we only want to schedule spellchecks for ranges that are visible
-    foreach (KTextEditor::View *i, m_document->views()) {
+    const auto views = m_document->views();
+    for (KTextEditor::View *i : views) {
         KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(i);
         KTextEditor::Range visibleIntersection = documentIntersection.intersect(view->visibleRange());
         if (visibleIntersection.isValid()) { // see above
@@ -263,12 +257,10 @@ inline bool rangesAdjacent(const KTextEditor::Range &r1, const KTextEditor::Rang
 
 void KateOnTheFlyChecker::handleRemovedText(const KTextEditor::Range &range)
 {
-
     ON_THE_FLY_DEBUG << range;
 
     QList<KTextEditor::Range> rangesToReCheck;
-    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin();
-            i != m_spellCheckQueue.end();) {
+    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin(); i != m_spellCheckQueue.end();) {
         KTextEditor::MovingRange *spellCheckRange = (*i).first;
         if (rangesAdjacent(*spellCheckRange, range) || spellCheckRange->contains(range)) {
             ON_THE_FLY_DEBUG << "erasing range " << *i;
@@ -286,9 +278,7 @@ void KateOnTheFlyChecker::handleRemovedText(const KTextEditor::Range &range)
     if (spellCheckInProgress) {
         KTextEditor::MovingRange *spellCheckRange = m_currentlyCheckedItem.first;
         ON_THE_FLY_DEBUG << *spellCheckRange;
-        if (m_document->documentRange().contains(*spellCheckRange)
-                && (rangesAdjacent(*spellCheckRange, range) || spellCheckRange->contains(range))
-                && !spellCheckRange->isEmpty()) {
+        if (m_document->documentRange().contains(*spellCheckRange) && (rangesAdjacent(*spellCheckRange, range) || spellCheckRange->contains(range)) && !spellCheckRange->isEmpty()) {
             rangesToReCheck.push_back(*spellCheckRange);
             ON_THE_FLY_DEBUG << "added the range " << *spellCheckRange;
             stopCurrentSpellCheck();
@@ -310,7 +300,7 @@ void KateOnTheFlyChecker::handleRemovedText(const KTextEditor::Range &range)
     queueSpellCheckVisibleRange(spellCheckRange);
 
     if (range.numberOfLines() > 0) {
-        //FIXME: there is no currently no way of doing this better as we only get notifications for removals of
+        // FIXME: there is no currently no way of doing this better as we only get notifications for removals of
         //       of single lines, i.e. we don't know here how many lines have been removed in total
         KTextEditor::Cursor nextLineStart(spellCheckEnd.line() + 1, 0);
         const KTextEditor::Cursor documentEnd = m_document->documentEnd();
@@ -340,8 +330,7 @@ void KateOnTheFlyChecker::freeDocument()
     ON_THE_FLY_DEBUG;
 
     // empty the spell check queue
-    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin();
-            i != m_spellCheckQueue.end();) {
+    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin(); i != m_spellCheckQueue.end();) {
         ON_THE_FLY_DEBUG << "erasing range " << *i;
         KTextEditor::MovingRange *movingRange = (*i).first;
         deleteMovingRangeQuickly(movingRange);
@@ -353,8 +342,8 @@ void KateOnTheFlyChecker::freeDocument()
     }
     stopCurrentSpellCheck();
 
-    MisspelledList misspelledList = m_misspelledList; // make a copy!
-    foreach (const MisspelledItem &i, misspelledList) {
+    const MisspelledList misspelledList = m_misspelledList; // make a copy!
+    for (const MisspelledItem &i : misspelledList) {
         deleteMovingRange(i.first);
     }
     m_misspelledList.clear();
@@ -383,12 +372,10 @@ void KateOnTheFlyChecker::performSpellCheck()
 
     m_currentDecToEncOffsetList.clear();
     KTextEditor::DocumentPrivate::OffsetList encToDecOffsetList;
-    QString text = m_document->decodeCharacters(*spellCheckRange,
-                   m_currentDecToEncOffsetList,
-                   encToDecOffsetList);
+    QString text = m_document->decodeCharacters(*spellCheckRange, m_currentDecToEncOffsetList, encToDecOffsetList);
     ON_THE_FLY_DEBUG << "next spell checking" << text;
     if (text.isEmpty()) { // passing an empty string to Sonnet can lead to a bad allocation exception
-        spellCheckDone();  // (bug 225867)
+        spellCheckDone(); // (bug 225867)
         return;
     }
     if (m_speller.language() != language) {
@@ -396,16 +383,31 @@ void KateOnTheFlyChecker::performSpellCheck()
     }
     if (!m_backgroundChecker) {
         m_backgroundChecker = new Sonnet::BackgroundChecker(m_speller, this);
-        connect(m_backgroundChecker,
-                SIGNAL(misspelling(QString,int)),
-                this,
-                SLOT(misspelling(QString,int)));
+        connect(m_backgroundChecker, SIGNAL(misspelling(QString, int)), this, SLOT(misspelling(QString, int)));
         connect(m_backgroundChecker, SIGNAL(done()), this, SLOT(spellCheckDone()));
+
+        KateSpellCheckManager *m_spellCheckManager = KTextEditor::EditorPrivate::self()->spellCheckManager();
+        connect(m_spellCheckManager, &KateSpellCheckManager::wordAddedToDictionary, this, &KateOnTheFlyChecker::addToDictionary);
+        connect(m_spellCheckManager, &KateSpellCheckManager::wordIgnored, this, &KateOnTheFlyChecker::addToSession);
     }
     m_backgroundChecker->setSpeller(m_speller);
     m_backgroundChecker->setText(text); // don't call 'start()' after this!
 }
 
+void KateOnTheFlyChecker::addToDictionary(const QString &word)
+{
+    if (m_backgroundChecker) {
+        m_backgroundChecker->addWordToPersonal(word);
+    }
+}
+
+void KateOnTheFlyChecker::addToSession(const QString &word)
+{
+    if (m_backgroundChecker) {
+        m_backgroundChecker->addWordToSession(word);
+    }
+}
+
 void KateOnTheFlyChecker::removeRangeFromEverything(KTextEditor::MovingRange *movingRange)
 {
     Q_ASSERT(m_document == movingRange->document());
@@ -432,8 +434,7 @@ void KateOnTheFlyChecker::removeRangeFromEverything(KTextEditor::MovingRange *mo
 
 bool KateOnTheFlyChecker::removeRangeFromCurrentSpellCheck(KTextEditor::MovingRange *range)
 {
-    if (m_currentlyCheckedItem != invalidSpellCheckQueueItem()
-            && m_currentlyCheckedItem.first == range) {
+    if (m_currentlyCheckedItem != invalidSpellCheckQueueItem() && m_currentlyCheckedItem.first == range) {
         stopCurrentSpellCheck();
         return true;
     }
@@ -458,8 +459,7 @@ bool KateOnTheFlyChecker::removeRangeFromSpellCheckQueue(KTextEditor::MovingRang
         return true;
     }
     bool found = false;
-    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin();
-            i != m_spellCheckQueue.end();) {
+    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin(); i != m_spellCheckQueue.end();) {
         if ((*i).first == range) {
             i = m_spellCheckQueue.erase(i);
             found = true;
@@ -515,27 +515,27 @@ void KateOnTheFlyChecker::deleteMovingRange(KTextEditor::MovingRange *range)
     ON_THE_FLY_DEBUG << range;
     // remove it from all our structures
     removeRangeFromEverything(range);
-    range->setFeedback(NULL);
-    foreach (KTextEditor::View *view, m_document->views()) {
+    range->setFeedback(nullptr);
+    const auto views = m_document->views();
+    for (KTextEditor::View *view : views) {
         static_cast<KTextEditor::ViewPrivate *>(view)->spellingMenu()->rangeDeleted(range);
     }
-    delete(range);
+    delete (range);
 }
 
 void KateOnTheFlyChecker::deleteMovingRanges(const QList<KTextEditor::MovingRange *> &list)
 {
-    foreach (KTextEditor::MovingRange *r, list) {
+    for (KTextEditor::MovingRange *r : list) {
         deleteMovingRange(r);
     }
 }
 
-KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cursor &begin,
-        const KTextEditor::Cursor &end)
+KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cursor &begin, const KTextEditor::Cursor &end)
 {
     // FIXME: QTextBoundaryFinder should be ideally used for this, but it is currently
     //        still broken in Qt
     const QRegExp boundaryRegExp(QLatin1String("\\b"));
-    const QRegExp boundaryQuoteRegExp(QLatin1String("\\b\\w+'\\w*$"));  // handle spell checking of QLatin1String("isn't"), QLatin1String("doesn't"), etc.
+    const QRegExp boundaryQuoteRegExp(QLatin1String("\\b\\w+'\\w*$")); // handle spell checking of QLatin1String("isn't"), QLatin1String("doesn't"), etc.
     const QRegExp extendedBoundaryRegExp(QLatin1String("(\\W|$)"));
     const QRegExp extendedBoundaryQuoteRegExp(QLatin1String("^\\w*'\\w+\\b")); // see above
     KTextEditor::DocumentPrivate::OffsetList decToEncOffsetList, encToDecOffsetList;
@@ -544,11 +544,8 @@ KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cu
     KTextEditor::Cursor boundaryStart, boundaryEnd;
     // first we take care of the start position
     const KTextEditor::Range startLineRange(startLine, 0, startLine, m_document->lineLength(startLine));
-    QString decodedLineText = m_document->decodeCharacters(startLineRange,
-                              decToEncOffsetList,
-                              encToDecOffsetList);
-    int translatedColumn = m_document->computePositionWrtOffsets(encToDecOffsetList,
-                           startColumn);
+    QString decodedLineText = m_document->decodeCharacters(startLineRange, decToEncOffsetList, encToDecOffsetList);
+    int translatedColumn = m_document->computePositionWrtOffsets(encToDecOffsetList, startColumn);
     QString text = decodedLineText.mid(0, translatedColumn);
     boundaryStart.setLine(startLine);
     int match = text.lastIndexOf(boundaryQuoteRegExp);
@@ -563,12 +560,9 @@ KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cu
         decToEncOffsetList.clear();
         encToDecOffsetList.clear();
         const KTextEditor::Range endLineRange(endLine, 0, endLine, m_document->lineLength(endLine));
-        decodedLineText = m_document->decodeCharacters(endLineRange,
-                          decToEncOffsetList,
-                          encToDecOffsetList);
+        decodedLineText = m_document->decodeCharacters(endLineRange, decToEncOffsetList, encToDecOffsetList);
     }
-    translatedColumn = m_document->computePositionWrtOffsets(encToDecOffsetList,
-                       endColumn);
+    translatedColumn = m_document->computePositionWrtOffsets(encToDecOffsetList, endColumn);
     text = decodedLineText.mid(translatedColumn);
     boundaryEnd.setLine(endLine);
     match = extendedBoundaryQuoteRegExp.indexIn(text);
@@ -577,8 +571,7 @@ KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cu
     } else {
         match = extendedBoundaryRegExp.indexIn(text);
     }
-    boundaryEnd.setColumn(m_document->computePositionWrtOffsets(decToEncOffsetList,
-                          translatedColumn + qMax(0, match)));
+    boundaryEnd.setColumn(m_document->computePositionWrtOffsets(decToEncOffsetList, translatedColumn + qMax(0, match)));
     return KTextEditor::Range(boundaryStart, boundaryEnd);
 }
 
@@ -588,24 +581,18 @@ void KateOnTheFlyChecker::misspelling(const QString &word, int start)
         ON_THE_FLY_DEBUG << "exited as no spell check is taking place";
         return;
     }
-    int translatedStart = m_document->computePositionWrtOffsets(m_currentDecToEncOffsetList,
-                          start);
-//   ON_THE_FLY_DEBUG << "misspelled " << word
-//                                     << " at line "
-//                                     << *m_currentlyCheckedItem.first
-//                                     << " column " << start;
+    int translatedStart = m_document->computePositionWrtOffsets(m_currentDecToEncOffsetList, start);
+    //   ON_THE_FLY_DEBUG << "misspelled " << word
+    //                                     << " at line "
+    //                                     << *m_currentlyCheckedItem.first
+    //                                     << " column " << start;
 
     KTextEditor::MovingRange *spellCheckRange = m_currentlyCheckedItem.first;
     int line = spellCheckRange->start().line();
     int rangeStart = spellCheckRange->start().column();
-    int translatedEnd = m_document->computePositionWrtOffsets(m_currentDecToEncOffsetList,
-                        start + word.length());
+    int translatedEnd = m_document->computePositionWrtOffsets(m_currentDecToEncOffsetList, start + word.length());
 
-    KTextEditor::MovingRange *movingRange =
-        m_document->newMovingRange(KTextEditor::Range(line,
-                                   rangeStart + translatedStart,
-                                   line,
-                                   rangeStart + translatedEnd));
+    KTextEditor::MovingRange *movingRange = m_document->newMovingRange(KTextEditor::Range(line, rangeStart + translatedStart, line, rangeStart + translatedEnd));
     movingRange->setFeedback(this);
     KTextEditor::Attribute *attribute = new KTextEditor::Attribute();
     attribute->setUnderlineStyle(QTextCharFormat::SpellCheckUnderline);
@@ -642,8 +629,7 @@ QList<KTextEditor::MovingRange *> KateOnTheFlyChecker::installedMovingRanges(con
     ON_THE_FLY_DEBUG << range;
     MovingRangeList toReturn;
 
-    for (QList<SpellCheckItem>::iterator i = m_misspelledList.begin();
-            i != m_misspelledList.end(); ++i) {
+    for (QList<SpellCheckItem>::iterator i = m_misspelledList.begin(); i != m_misspelledList.end(); ++i) {
         KTextEditor::MovingRange *movingRange = (*i).first;
         if (movingRange->overlaps(range)) {
             toReturn.push_back(movingRange);
@@ -655,7 +641,7 @@ QList<KTextEditor::MovingRange *> KateOnTheFlyChecker::installedMovingRanges(con
 void KateOnTheFlyChecker::updateConfig()
 {
     ON_THE_FLY_DEBUG;
-    //m_speller.restore();
+    // m_speller.restore();
 }
 
 void KateOnTheFlyChecker::refreshSpellCheck(const KTextEditor::Range &range)
@@ -673,8 +659,8 @@ void KateOnTheFlyChecker::addView(KTextEditor::Document *document, KTextEditor::
     Q_ASSERT(document == m_document);
     Q_UNUSED(document);
     ON_THE_FLY_DEBUG;
-    connect(view, SIGNAL(destroyed(QObject*)), this, SLOT(viewDestroyed(QObject*)));
-    connect(view, SIGNAL(displayRangeChanged(KTextEditor::ViewPrivate*)), this, SLOT(restartViewRefreshTimer(KTextEditor::ViewPrivate*)));
+    connect(view, SIGNAL(destroyed(QObject *)), this, SLOT(viewDestroyed(QObject *)));
+    connect(view, SIGNAL(displayRangeChanged(KTextEditor::ViewPrivate *)), this, SLOT(restartViewRefreshTimer(KTextEditor::ViewPrivate *)));
     updateInstalledMovingRanges(static_cast<KTextEditor::ViewPrivate *>(view));
 }
 
@@ -701,11 +687,12 @@ void KateOnTheFlyChecker::updateInstalledMovingRanges(KTextEditor::ViewPrivate *
     ON_THE_FLY_DEBUG << "new range: " << newDisplayRange;
     ON_THE_FLY_DEBUG << "old range: " << oldDisplayRange;
     QList<KTextEditor::MovingRange *> toDelete;
-    foreach (const MisspelledItem &item, m_misspelledList) {
+    for (const MisspelledItem &item : qAsConst(m_misspelledList)) {
         KTextEditor::MovingRange *movingRange = item.first;
         if (!movingRange->overlaps(newDisplayRange)) {
             bool stillVisible = false;
-            foreach (KTextEditor::View *it2, m_document->views()) {
+            const auto views = m_document->views();
+            for (KTextEditor::View *it2 : views) {
                 KTextEditor::ViewPrivate *view2 = static_cast<KTextEditor::ViewPrivate *>(it2);
                 if (view != view2 && movingRange->overlaps(view2->visibleRange())) {
                     stillVisible = true;
@@ -724,7 +711,8 @@ void KateOnTheFlyChecker::updateInstalledMovingRanges(KTextEditor::ViewPrivate *
         for (int line = newDisplayRange.end().line(); line >= newDisplayRange.start().line(); --line) {
             if (!oldDisplayRange.containsLine(line)) {
                 bool visible = false;
-                foreach (KTextEditor::View *it2, m_document->views()) {
+                const auto views = m_document->views();
+                for (KTextEditor::View *it2 : views) {
                     KTextEditor::ViewPrivate *view2 = static_cast<KTextEditor::ViewPrivate *>(it2);
                     if (view != view2 && view2->visibleRange().containsLine(line)) {
                         visible = true;
@@ -764,12 +752,9 @@ void KateOnTheFlyChecker::queueSpellCheckVisibleRange(KTextEditor::ViewPrivate *
     const MovingRangeList highlightsList = installedMovingRanges(intersection);
     deleteMovingRanges(highlightsList);
 
-    QList<QPair<KTextEditor::Range, QString> > spellCheckRanges
-        = KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(m_document,
-                intersection,
-                true);
-    //we queue them up in reverse
-    QListIterator<QPair<KTextEditor::Range, QString> > i(spellCheckRanges);
+    QList<QPair<KTextEditor::Range, QString>> spellCheckRanges = KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(m_document, intersection, true);
+    // we queue them up in reverse
+    QListIterator<QPair<KTextEditor::Range, QString>> i(spellCheckRanges);
     i.toBack();
     while (i.hasPrevious()) {
         QPair<KTextEditor::Range, QString> p = i.previous();
@@ -786,12 +771,9 @@ void KateOnTheFlyChecker::queueLineSpellCheck(KTextEditor::DocumentPrivate *kate
     const MovingRangeList highlightsList = installedMovingRanges(range);
     deleteMovingRanges(highlightsList);
 
-    QList<QPair<KTextEditor::Range, QString> > spellCheckRanges
-        = KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(kateDocument,
-                range,
-                true);
-    //we queue them up in reverse
-    QListIterator<QPair<KTextEditor::Range, QString> > i(spellCheckRanges);
+    QList<QPair<KTextEditor::Range, QString>> spellCheckRanges = KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(kateDocument, range, true);
+    // we queue them up in reverse
+    QListIterator<QPair<KTextEditor::Range, QString>> i(spellCheckRanges);
     i.toBack();
     while (i.hasPrevious()) {
         QPair<KTextEditor::Range, QString> p = i.previous();
@@ -824,8 +806,7 @@ void KateOnTheFlyChecker::addToSpellCheckQueue(KTextEditor::MovingRange *range,
     range->setFeedback(this);
 
     // if the queue contains a subrange of 'range', we remove that one
-    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin();
-            i != m_spellCheckQueue.end();) {
+    for (QList<SpellCheckItem>::iterator i = m_spellCheckQueue.begin(); i != m_spellCheckQueue.end();) {
         KTextEditor::MovingRange *spellCheckRange = (*i).first;
         if (range->contains(*spellCheckRange)) {
             deleteMovingRangeQuickly(spellCheckRange);
@@ -836,9 +817,7 @@ void KateOnTheFlyChecker::addToSpellCheckQueue(KTextEditor::MovingRange *range,
     }
     // leave 'push_front' here as it is a LIFO queue, i.e. a stack
     m_spellCheckQueue.push_front(SpellCheckItem(range, dictionary));
-    ON_THE_FLY_DEBUG << "added"
-                     << *range << dictionary
-                     << "to the queue, which has a length of" << m_spellCheckQueue.size();
+    ON_THE_FLY_DEBUG << "added" << *range << dictionary << "to the queue, which has a length of" << m_spellCheckQueue.size();
 }
 
 void KateOnTheFlyChecker::viewRefreshTimeout()
@@ -846,12 +825,12 @@ void KateOnTheFlyChecker::viewRefreshTimeout()
     if (m_refreshView) {
         updateInstalledMovingRanges(m_refreshView);
     }
-    m_refreshView = NULL;
+    m_refreshView = nullptr;
 }
 
 void KateOnTheFlyChecker::restartViewRefreshTimer(KTextEditor::ViewPrivate *view)
 {
-    if (m_refreshView && view != m_refreshView) { // a new view should be refreshed
+    if (m_refreshView && view != m_refreshView) {   // a new view should be refreshed
         updateInstalledMovingRanges(m_refreshView); // so refresh the old one first
     }
     m_refreshView = view;
@@ -860,16 +839,17 @@ void KateOnTheFlyChecker::restartViewRefreshTimer(KTextEditor::ViewPrivate *view
 
 void KateOnTheFlyChecker::deleteMovingRangeQuickly(KTextEditor::MovingRange *range)
 {
-    range->setFeedback(NULL);
-    foreach (KTextEditor::View *view, m_document->views()) {
+    range->setFeedback(nullptr);
+    const auto views = m_document->views();
+    for (KTextEditor::View *view : views) {
         static_cast<KTextEditor::ViewPrivate *>(view)->spellingMenu()->rangeDeleted(range);
     }
-    delete(range);
+    delete (range);
 }
 
 void KateOnTheFlyChecker::handleModifiedRanges()
 {
-    foreach (const ModificationItem &item, m_modificationList) {
+    for (const ModificationItem &item : qAsConst(m_modificationList)) {
         KTextEditor::MovingRange *movingRange = item.second;
         KTextEditor::Range range = *movingRange;
         deleteMovingRangeQuickly(movingRange);
@@ -900,7 +880,7 @@ bool KateOnTheFlyChecker::removeRangeFromModificationList(KTextEditor::MovingRan
 
 void KateOnTheFlyChecker::clearModificationList()
 {
-    foreach (const ModificationItem &item, m_modificationList) {
+    for (const ModificationItem &item : qAsConst(m_modificationList)) {
         KTextEditor::MovingRange *movingRange = item.second;
         deleteMovingRangeQuickly(movingRange);
     }
